(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6572,        229]*)
(*NotebookOutlinePosition[      7236,        252]*)
(*  CellTagsIndexPosition[      7192,        248]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["16.21 Techniques of structural analysis and design", "Title",
  TextAlignment->Center,
  FontSize->18],

Cell["\<\
Home assignment 8
Solution Set
\
\>", "Subtitle",
  TextAlignment->Center,
  FontSize->18],

Cell["Question 1: Problem 7.43 from textbook", "Subtitle"],

Cell[TextData[{
  StyleBox["The unknown displacement field for this problem is the deflection \
of the beam's neutral axis ", "Subsubtitle",
    FontSize->18],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\((w\_0)\) . \ 
          We\ approximate\ this\ field\ using\ a\ Ritz\ approximation\ of\ \
the\ \(type : \[IndentingNewLine]w\_0\ ~\ c\_i  \[Phi]\_i\)\)], "Subsubtitle",
    
    FontSize->18], "Subsubtitle"],
  StyleBox["\n\n", "Subsubtitle"],
  StyleBox["The essential boundary conditions at the clamped end (x=0) of \
this cantilever beam require:\n", "Subsubtitle",
    FontSize->18],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_i\)(0)\)], "Subsubtitle",
    FontSize->18], "Subsubtitle"],
  StyleBox["=0, ", "Subsubtitle",
    FontSize->18],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i'\)], "Subsubtitle",
    FontSize->18], "Subsubtitle"],
  StyleBox["(0) = 0\nA good candidate family of functions ", "Subsubtitle",
    FontSize->18],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)], "Subsubtitle",
    FontSize->18], "Subsubtitle"],
  StyleBox["would be: ", "Subsubtitle",
    FontSize->18],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i = \ \(x\/L\)\^\(i + 1\), \ i = 1, n\)], 
    "Subsubtitle",
    FontSize->18], "Subsubtitle"],
  StyleBox[". Note ", "Subsubtitle",
    FontSize->18],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\^1\)], "Subsubtitle",
    FontSize->18], "Subsubtitle"],
  StyleBox[" does not satisfy  the zero-slope boundary condition so it's been \
eliminated.", "Subsubtitle",
    FontSize->18]
}], "Subtitle",
  FontSize->168],

Cell[BoxData[
    \(\(\( (*\ 
      clean\ all\ the\ variables\ \
*) \)\(\[IndentingNewLine]\)\(Clear["\<Global`*\>"]; 
    Off[General::spell, General::spell1];\)\)\)], "Input",
  FontSize->24],

Cell[CellGroupData[{

Cell["1) approximation functions:", "Subtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Ck[n_] := \ Table[ck[i], {i, n}]\), "\[IndentingNewLine]", 
    \(\[Phi]k[n_]\  := \ 
      Table[\((x\/L)\)\^\(i + 1\), {i, n}]\), "\[IndentingNewLine]", 
    \(w[n_]\  := \ Ck[n] . \[Phi]k[n]\), "\[IndentingNewLine]", 
    \(w[2]\)}], "Input",
  FontSize->24],

Cell[BoxData[
    \(\(x\^2\ ck[1]\)\/L\^2 + \(x\^3\ ck[2]\)\/L\^3\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2) approximate potential \[CapitalPi](Ck) for this problem\
\>", \
"Subtitle",
  FontSize->24],

Cell[BoxData[{
    \(\[Delta]\_L[n_]\  := \ 
      w[n]\  /. \ x \[Rule] \ L\), "\[IndentingNewLine]", 
    \(\[CapitalPi][
        n_]\  := \(EI\/2\) \(\[Integral]\_0\%L\ \(\((\[PartialD]\_\(x, x\)w[
                          n])\)\^2\) \[DifferentialD]x\)\  + \ 
          k\/2\ \[Delta]\_L[n]\^2 - \ \[Integral]\_0\%L\( q\_0\) 
              w[n] \[DifferentialD]x // Expand\)}], "Input",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalPi][2]\)], "Input"],

Cell[BoxData[
    \(1\/2\ k\ ck[1]\^2 + \(2\ EI\ ck[1]\^2\)\/L\^3 + 
      k\ ck[1]\ ck[2] + \(6\ EI\ ck[1]\ ck[2]\)\/L\^3 + 
      1\/2\ k\ ck[2]\^2 + \(6\ EI\ ck[2]\^2\)\/L\^3 - 1\/3\ L\ ck[1]\ q\_0 - 
      1\/4\ L\ ck[2]\ q\_0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3) Minimize the potential to find the value of the coefficients \
that best approximate this problem\
\>", "Subtitle",
  FontSize->24],

Cell[BoxData[
    \(grad\[CapitalPi][n_]\  := \ 
      Table[D[\[CapitalPi][n], ck[i]], {i, n}]\)], "Input",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
    \(grad\[CapitalPi][2]\)], "Input",
  FontSize->24],

Cell[BoxData[
    \({k\ ck[1] + \(4\ EI\ ck[1]\)\/L\^3 + 
        k\ ck[2] + \(6\ EI\ ck[2]\)\/L\^3 - \(L\ q\_0\)\/3, 
      k\ ck[1] + \(6\ EI\ ck[1]\)\/L\^3 + 
        k\ ck[2] + \(12\ EI\ ck[2]\)\/L\^3 - \(L\ q\_0\)\/4}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(solution[n_]\  := \ 
      Solve[grad\[CapitalPi][n]\  \[Equal] \ 0\ , \ Ck[n]] // 
        Flatten\)], "Input",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution[1]\)], "Input",
  FontSize->24],

Cell[BoxData[
    \({ck[
          1] \[Rule] \(L\^4\ q\_0\)\/\(3\ \((4\ EI + k\ L\^3)\)\)}\)], \
"Output"]
}, Open  ]],

Cell[BoxData[
    \(wapprox[n_]\  := \ w[n]\  /. \ solution[n]\)], "Input",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
    \(wapprox[1]\)], "Input",
  FontSize->24],

Cell[BoxData[
    \(\(L\^2\ x\^2\ q\_0\)\/\(3\ \((4\ EI + k\ L\^3)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
WindowSize->{843, 610},
WindowMargins->{{76, Automatic}, {Automatic, 121}},
StyleDefinitions -> "Report.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 108, 2, 59, "Title"],
Cell[1887, 57, 100, 6, 75, "Subtitle"],
Cell[1990, 65, 58, 0, 39, "Subtitle"],
Cell[2051, 67, 1637, 42, 192, "Subtitle"],
Cell[3691, 111, 194, 5, 103, "Input"],

Cell[CellGroupData[{
Cell[3910, 120, 63, 1, 39, "Subtitle"],

Cell[CellGroupData[{
Cell[3998, 125, 282, 6, 169, "Input"],
Cell[4283, 133, 79, 1, 64, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4411, 140, 104, 4, 39, "Subtitle"],
Cell[4518, 146, 407, 8, 176, "Input"],

Cell[CellGroupData[{
Cell[4950, 158, 48, 1, 32, "Input"],
Cell[5001, 161, 244, 4, 101, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5294, 171, 144, 4, 66, "Subtitle"],
Cell[5441, 177, 124, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[5590, 184, 68, 2, 43, "Input"],
Cell[5661, 188, 236, 4, 63, "Output"]
}, Open  ]],
Cell[5912, 195, 148, 4, 73, "Input"],

Cell[CellGroupData[{
Cell[6085, 203, 60, 2, 43, "Input"],
Cell[6148, 207, 107, 3, 66, "Output"]
}, Open  ]],
Cell[6270, 213, 91, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[6386, 219, 59, 2, 43, "Input"],
Cell[6448, 223, 84, 1, 66, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

