(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     54363,       1405]*)
(*NotebookOutlinePosition[     54995,       1427]*)
(*  CellTagsIndexPosition[     54951,       1423]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  Cell[BoxData[{
      \(TraditionalForm\`u''\  + \ u\  + \ x\  = \ 0, \ 0 < x < 1\ \), 
    "\[IndentingNewLine]", 
      \(TraditionalForm\`u(
          0)\  = \ \(\(u(1)\)\(\ \)\(=\)\(\ \)\(0\)\(\ \)\)\)}]],
  "\n\na) Weak form: multiply differential equation by admissible virtual \
field \[Delta]u, integrate between (0,1), integrate by parts:\n",
  Cell[BoxData[
      \(TraditionalForm\`0 = \(\[Integral]\_0\%1\((u''\  + \ u\  + \ 
                  x)\)\ \[Delta]u \[DifferentialD]x\  = \[IndentingNewLine]\(\
\[Integral]\_0\%1\((\(-u'\)\ \[Delta]u'\  + \ \((u'\ \[Delta]u)\)'\  + \ 
                    u\ \[Delta]u\  + \ 
                    x\ \[Delta]u)\)\ \[DifferentialD]x\  = \
\[IndentingNewLine]\ \ u'\ \[Delta]u\( | \
\_0\)\^1\(+\(\[Integral]\_0\%1\((\(-u'\)\ \[Delta]u'\ \  + \ 
                        u\ \[Delta]u\  + \ 
                        x\ \[Delta]u)\)\ \[DifferentialD]x\)\)\)\)\)]],
  "\n\nAdmissibility requires the boundary terms to vanish, The weak form is \
therefore:\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%1\((\(-u'\)\ \[Delta]u'\ \  + \ 
                u\ \[Delta]u\  + \ x\ \[Delta]u)\)\ \[DifferentialD]x = 
        0, \ \[ForAll] \ \[Delta]u\ s . 
              t . \ \(\[Delta]u(0)\)\  = \ \(\[Delta]u(1)\  = \ 0\)\)]],
  "\n"
}], "Subtitle"],

Cell["Approximation:", "Subtitle"],

Cell[BoxData[{
    \(\[CapitalPhi][n_] := 
      Table[\[Phi]\_i = \ x\ \((1 - x)\)\ x\^\(i - 1\), {i, 
          n}]\), "\[IndentingNewLine]", 
    \(Ck[n_]\  := \ Table\ [c[i], {i, n}]\), "\[IndentingNewLine]", 
    \(U\_N[n_]\  := \ \[CapitalPhi][n] . Ck[n]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(U\_N[10]\)], "Input"],

Cell[BoxData[
    \(\((1 - x)\)\ x\ c[1] + \((1 - x)\)\ x\^2\ c[2] + \((1 - x)\)\ x\^3\ c[
          3] + \((1 - x)\)\ x\^4\ c[4] + \((1 - x)\)\ x\^5\ c[
          5] + \((1 - x)\)\ x\^6\ c[6] + \((1 - x)\)\ x\^7\ c[
          7] + \((1 - x)\)\ x\^8\ c[8] + \((1 - x)\)\ x\^9\ c[
          9] + \((1 - x)\)\ x\^10\ c[10]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]\_3\)], "Input"],

Cell[BoxData[
    \(\((1 - x)\)\ x\^3\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(K[n_] := \ 
      Table[\[Integral]\_0\%1\((\(-\[Phi]\_i\)\ \[Phi]\_j\  + \ \
\[PartialD]\_x \[Phi]\_i \[PartialD]\_x \[Phi]\_j)\) \[DifferentialD]x, {i, 
          n}, {j, n}]\), "\[IndentingNewLine]", 
    \(R[n_]\  := \ 
      Table[\[Integral]\_0\%1 x\ \(\[Phi]\_i\) \[DifferentialD]x, \ {i, 
          n}]\)}], "Input"],

Cell[BoxData[
    \(sol[n_]\  := \ Inverse[K[n]] . R[n]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol[4] // N\)], "Input"],

Cell[BoxData[
    \({0.18837807519082037`, 
      0.18862423414593366`, \(-0.010522424485733158`\), \
\(-0.008592631167816691`\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(uh[n_] := \ sol[n] . \[CapitalPhi][n]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(uh[1]\)], "Input"],

Cell[BoxData[
    \(5\/18\ \((1 - x)\)\ x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(u\  = \ Sin[x]\/Sin[1] - x\)], "Input"],

Cell[BoxData[
    \(\(-x\) + Csc[1]\ Sin[x]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 1;\)\), "\[IndentingNewLine]", 
    \(\(up\  = \ uh[n];\)\), "\[IndentingNewLine]", 
    \(Plot[{u, up}, {x, 0, 1}, \ 
      PlotStyle \[Rule] {Thickness[0.01], {Thickness[0.01], 
            Dashing[{0.05, 0.025}], 
            RGBColor[1, 0, 0]}}]\), "\[IndentingNewLine]", 
    \(\(n = 2;\)\), "\[IndentingNewLine]", 
    \(\(up\  = \ uh[n];\)\), "\[IndentingNewLine]", 
    \(Plot[{u, up}, {x, 0, 1}, \ 
      PlotStyle \[Rule] {Thickness[0.015], {Thickness[0.02], 
            Dashing[{0.05, 0.05}], RGBColor[1, 0, 0]}}]\)}], "Input"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 8.25574 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .09727 -24 -4.5 ]
[.01131 .09727 0 4.5 ]
[.01131 .17983 -24 -4.5 ]
[.01131 .17983 0 4.5 ]
[.01131 .26239 -24 -4.5 ]
[.01131 .26239 0 4.5 ]
[.01131 .34494 -24 -4.5 ]
[.01131 .34494 0 4.5 ]
[.01131 .4275 -24 -4.5 ]
[.01131 .4275 0 4.5 ]
[.01131 .51006 -24 -4.5 ]
[.01131 .51006 0 4.5 ]
[.01131 .59262 -24 -4.5 ]
[.01131 .59262 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09727 m
.03006 .09727 L
s
[(0.01)] .01131 .09727 1 0 Mshowa
.02381 .17983 m
.03006 .17983 L
s
[(0.02)] .01131 .17983 1 0 Mshowa
.02381 .26239 m
.03006 .26239 L
s
[(0.03)] .01131 .26239 1 0 Mshowa
.02381 .34494 m
.03006 .34494 L
s
[(0.04)] .01131 .34494 1 0 Mshowa
.02381 .4275 m
.03006 .4275 L
s
[(0.05)] .01131 .4275 1 0 Mshowa
.02381 .51006 m
.03006 .51006 L
s
[(0.06)] .01131 .51006 1 0 Mshowa
.02381 .59262 m
.03006 .59262 L
s
[(0.07)] .01131 .59262 1 0 Mshowa
.125 Mabswid
.02381 .03123 m
.02756 .03123 L
s
.02381 .04774 m
.02756 .04774 L
s
.02381 .06425 m
.02756 .06425 L
s
.02381 .08076 m
.02756 .08076 L
s
.02381 .11378 m
.02756 .11378 L
s
.02381 .1303 m
.02756 .1303 L
s
.02381 .14681 m
.02756 .14681 L
s
.02381 .16332 m
.02756 .16332 L
s
.02381 .19634 m
.02756 .19634 L
s
.02381 .21285 m
.02756 .21285 L
s
.02381 .22936 m
.02756 .22936 L
s
.02381 .24588 m
.02756 .24588 L
s
.02381 .2789 m
.02756 .2789 L
s
.02381 .29541 m
.02756 .29541 L
s
.02381 .31192 m
.02756 .31192 L
s
.02381 .32843 m
.02756 .32843 L
s
.02381 .36146 m
.02756 .36146 L
s
.02381 .37797 m
.02756 .37797 L
s
.02381 .39448 m
.02756 .39448 L
s
.02381 .41099 m
.02756 .41099 L
s
.02381 .44401 m
.02756 .44401 L
s
.02381 .46053 m
.02756 .46053 L
s
.02381 .47704 m
.02756 .47704 L
s
.02381 .49355 m
.02756 .49355 L
s
.02381 .52657 m
.02756 .52657 L
s
.02381 .54308 m
.02756 .54308 L
s
.02381 .55959 m
.02756 .55959 L
s
.02381 .57611 m
.02756 .57611 L
s
.02381 .60913 m
.02756 .60913 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.02381 .01472 m
.06244 .0777 L
.10458 .14562 L
.14415 .20795 L
.18221 .26588 L
.22272 .32469 L
.26171 .37782 L
.30316 .42983 L
.34309 .47486 L
.3815 .51284 L
.42237 .54681 L
.46172 .57258 L
.48147 .58276 L
.49955 .59036 L
.51896 .59664 L
.52966 .59924 L
.535 .6003 L
.53984 .60113 L
.54444 .6018 L
.54943 .60238 L
.55217 .60264 L
.55469 .60285 L
.55725 .60302 L
.55964 .60314 L
.5617 .60322 L
.56286 .60326 L
.56391 .60328 L
.56506 .6033 L
.56631 .60332 L
.56749 .60332 L
.56859 .60331 L
.56971 .6033 L
.57076 .60329 L
.57192 .60326 L
.57317 .60322 L
.5757 .60312 L
.57803 .60299 L
.58277 .60262 L
.58784 .60209 L
.59696 .60073 L
.6078 .59845 L
.61766 .59575 L
.63684 .58871 L
.65764 .57839 L
.69856 .54956 L
.73796 .51068 L
.77585 .4625 L
.81619 .39908 L
.85501 .32576 L
.89629 .2341 L
Mistroke
.93605 .13199 L
.97429 .02058 L
.97619 .01472 L
Mfstroke
1 0 0 r
[ .05 .025 ] 0 setdash
.02381 .01472 m
.06244 .10397 L
.10458 .19271 L
.14415 .26787 L
.18221 .33269 L
.22272 .39364 L
.26171 .44447 L
.30316 .49006 L
.34309 .52578 L
.3815 .55253 L
.40095 .56322 L
.42237 .57279 L
.44268 .57972 L
.45178 .58215 L
.46172 .58432 L
.4671 .58529 L
.4721 .58606 L
.47727 .58672 L
.48196 .58721 L
.48658 .58758 L
.4887 .58771 L
.49093 .58782 L
.49332 .58792 L
.49438 .58795 L
.49552 .58798 L
.49675 .588 L
.49789 .58802 L
.49859 .58803 L
.49925 .58803 L
.50049 .58803 L
.50163 .58802 L
.50286 .58801 L
.50401 .58799 L
.50508 .58797 L
.50754 .58789 L
.51014 .58777 L
.51268 .58762 L
.51504 .58746 L
.5204 .58698 L
.5293 .58586 L
.53882 .58422 L
.54906 .58195 L
.56016 .57888 L
.58032 .57172 L
.60019 .56265 L
.62123 .55087 L
.65912 .52401 L
.69946 .48744 L
.73829 .44447 L
.77956 .39043 L
Mistroke
.81932 .33022 L
.85757 .26477 L
.89827 .187 L
.93745 .10421 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00AP3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool4000002@0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000002@0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0P00000Z0?ooo`@000001P3oool004D0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000[0?ooo`030000003o
ool0oooo00D0oooo00150?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool08`3o
ool010000000oooo0?ooo`0000070?ooo`D000008`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
000[0?ooo`030000003oool0oooo00D0oooo00150?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool08P3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000002@0
oooo00@000000?ooo`3oool00000203oool3000002<0oooo00@000000?ooo`3oool000002@3oool2
000002`0oooo00<000000?ooo`3oool01@3oool004D0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`000000903o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000[0?ooo`030000003oool0oooo00D0oooo00150?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000008`3oool010000000oooo0?ooo`00
00090?ooo`800000903oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo02<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000Y0?ooo`<000001`3oool001/0
oooo00<000000?ooo`3oool0:03oool2000000X0oooo0P00000U0?ooo`8000002`3oool00`000000
oooo0?ooo`0S0?ooo`8000002P3oool3000002<0oooo0P00000:0?ooo`800000;03oool00`000000
oooo0?ooo`050?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<0o`000?ooo`3oool0o`3oool30?ooo`00503oool60000
00<0o`00o`000004000000006`3oool20?l000X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`3o0000
00000?ooo`060?ooo`006`3oool20?l000030000003oool0oooo02d0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
;P3oool30?l000L0oooo000K0?ooo`030000003o0000o`000?P0oooo0P3o00000`000000oooo0?oo
o`050?ooo`006`3oool010000000o`000?l00000003g0?ooo`80o`0000<000000?ooo`3oool01@3o
ool001/0oooo00D000000?l0003o0000o`000000003e0?ooo`80o`0000<000000?ooo`3oool01P3o
ool001/0oooo00D000000?ooo`3o0000o`000000003e0?ooo`80o`0000<000000?ooo`3oool01P3o
ool001/0oooo00@000000?ooo`3o0000o`000P00003d0?ooo`80o`0000<000000?ooo`3oool01P3o
ool001/0oooo00<000000?ooo`3oool00P3o00000`000000oooo0?ooo`3a0?ooo`80o`0000<00000
0?ooo`3oool01`3oool001/0oooo0P0000000`3oool0o`000?l0000200000?80oooo0P3o00000`00
0000oooo0?ooo`070?ooo`006`3oool00`000000oooo0?ooo`030?l000800000l03oool20?l00080
00002@3oool001/0oooo00H000000?ooo`3oool0oooo0?l0003oool200000?00oooo0P3o00000`00
0000oooo0?ooo`080?ooo`006`3oool00`000000oooo0?ooo`030?ooo`<00000k`3oool20?l00003
0000003oool0oooo00P0oooo000K0?ooo`8000001@3oool200000>h0oooo0P3o00000`000000oooo
0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`050?ooo`800000k@3oool20?l000030000003o
ool0oooo00T0oooo000K0?ooo`030000003oool0oooo00@0oooo00<0o`00000000000000k03oool3
0?l000030000003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo00<0oooo0`3o00020000
0>`0oooo00<0o`000000003oool02`3oool001/0oooo00<000000?ooo`3oool0103oool20?l000<0
0000j`3oool2000000`0oooo000K0?ooo`8000001@3oool20?l000030?ooo`00000000000>X0oooo
0`00000<0?ooo`006`3oool00`000000oooo0?ooo`050?ooo`80o`0000<0oooo000000000000j@3o
ool2000000d0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool4
000000@0oooo00<000000?ooo`3oool01@3oool20?l000040?ooo`000000000000000>H0oooo00@0
o`000?ooo`00000000003@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool20?l00080
oooo0P00003U0?ooo`<0o`0000<000000?ooo`3oool0303oool000050?ooo`000000oooo0?ooo`00
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo0P0000070?oo
o`80o`0000@0oooo0000000000000000i03oool20?l0008000003P3oool000050?ooo`000000oooo
0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool20?l00080oooo0P00003T0?ooo`80o`000P00000>0?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`<0o`000P3oool200000>80oooo0`3o00000`000000oooo
0?ooo`0=0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080
oooo0`0000050?ooo`030000003oool0oooo00L0oooo0P3o00020?ooo`<00000h@3oool20?l00080
00003`3oool00080oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`800000
203oool30?l00080oooo0P00003Q0?ooo`80o`0000<000000?ooo`3oool03P3oool001/0oooo00<0
00000?ooo`3oool0203oool20?l00080oooo0`00003O0?ooo`80o`000P00000@0?ooo`006`3oool0
0`000000oooo0?ooo`080?ooo`<0o`000P3oool200000=l0oooo0P3o000200000100oooo000K0?oo
o`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool00P3oool200000=d0oooo0P3o00020000
0140oooo000K0?ooo`030000003oool0oooo00h0oooo0`00003L0?ooo`80o`000P00000A0?ooo`00
6`3oool200000100oooo0P00003K0?ooo`80o`000`00000A0?ooo`006`3oool00`000000oooo0?oo
o`0?0?ooo`<00000fP3oool20?l0008000004P3oool001/0oooo00<000000?ooo`3oool0303oool0
103o0000oooo0?ooo`3oool200000=T0oooo0`3o000200000180oooo000K0?ooo`030000003oool0
oooo00/0oooo0`3o00030?ooo`800000f@3oool00`3o000000000000000C0?ooo`006`3oool20000
00d0oooo0P3o00030?ooo`<00000f@3oool2000001<0oooo000K0?ooo`030000003oool0oooo00`0
oooo0`3o00030?ooo`800000f@3oool2000001<0oooo000K0?ooo`030000003oool0oooo00d0oooo
0P3o00040?ooo`800000e`3oool2000001@0oooo000K0?ooo`030000003oool0oooo00d0oooo0`3o
00030?ooo`<00000d`3oool00`3o0000oooo0?ooo`02000001@0oooo000K0?ooo`8000003`3oool2
0?l000@0oooo0P00003B0?ooo`<0o`000`00000D0?ooo`006`3oool00`000000oooo0?ooo`0>0?oo
o`<0o`00103oool200000=40oooo0P3o00000`3oool000000000000E0?ooo`006`3oool00`000000
oooo0?ooo`0?0?ooo`80o`00103oool300000<l0oooo0`3o00000`3oool000000000000E0?ooo`00
0P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo100000040?ooo`030000
003oool0oooo00l0oooo0`3o00040?ooo`<00000cP3oool20?l000030?ooo`000000000001H0oooo
00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0100oooo0P3o00050?ooo`800000c@3oool20?l00080
oooo0P00000F0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0103oool200000140oooo0`3o00040?ooo`<00000b`3oool30?l0
0080oooo0P00000F0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`80o`001@3oool3
00000<X0oooo0P3o00020?ooo`8000005`3oool000050?ooo`000000oooo0?ooo`000000203oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3o
ool30?l000D0oooo0P0000390?ooo`<0o`000P3oool2000001L0oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0180oooo00<0o`000?ooo`3oool01@3oool200000<P0oooo0P3o00030?ooo`80
00005`3oool00080oooo0P00000:0?ooo`800000103oool2000000D0oooo0P00000K0?ooo`<00000
a`3oool20?l00080oooo0P00000H0?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`800000aP3o
ool20?l000<0oooo0P00000H0?ooo`006`3oool00`000000oooo0?ooo`0L0?ooo`800000a@3oool2
0?l00080oooo0`00000H0?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo
00@0oooo0`0000330?ooo`<0o`000P3oool2000001T0oooo000K0?ooo`030000003oool0oooo01@0
oooo0`3o00060?ooo`800000a03oool0103o0000oooo0?ooo`3oool2000001T0oooo000K0?ooo`80
00005P3oool20?l000L0oooo0P0000360?ooo`8000006P3oool001/0oooo00<000000?ooo`3oool0
5@3oool30?l000H0oooo0`0000350?ooo`8000006P3oool001/0oooo00<000000?ooo`3oool05P3o
ool20?l000L0oooo0P0000350?ooo`8000006P3oool001/0oooo00<000000?ooo`3oool05P3oool3
0?l000H0oooo0`00002n0?ooo`030?l0003oool0oooo0080oooo0P00000K0?ooo`006`3oool20000
01P0oooo0P3o00070?ooo`800000_@3oool30?l000<0oooo0P00000K0?ooo`006`3oool00`000000
oooo0?ooo`0G0?ooo`<0o`001`3oool200000;`0oooo0P3o00030?ooo`<000006`3oool001/0oooo
00<000000?ooo`3oool0603oool20?l000L0oooo0`00002j0?ooo`<0o`000`3oool2000001`0oooo
000K0?ooo`030000003oool0oooo01P0oooo0`3o00070?ooo`800000^P3oool20?l000@0oooo0P00
000L0?ooo`006`3oool2000001X0oooo0P3o00080?ooo`800000^03oool20?l000@0oooo0P00000M
0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`<0o`001`3oool300000;L0oooo0P3o00040?oo
o`8000007@3oool001/0oooo00<000000?ooo`3oool06P3oool20?l000P0oooo0P00002f0?ooo`80
o`00103oool2000001h0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool06P3oool30?l000L0oooo0`00002d0?ooo`<0o`00
103oool2000001h0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo00<0o`000?oo
o`3oool01`3oool200000;@0oooo0P3o00040?ooo`<000007P3oool000050?ooo`000000oooo0?oo
o`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo0P00000W
0?ooo`800000/P3oool30?l000@0oooo0P00000O0?ooo`0000D0oooo0000003oool0oooo00000008
0?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003oool0oooo02H0oooo0`00
002`0?ooo`<0o`00103oool3000001l0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo
00<0o`000?ooo`3oool01P3oool200000:l0oooo0`3o00050?ooo`800000803oool000050?ooo`00
0000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool07@3oool30?l000P0oooo0P00002_0?ooo`030?l0003oool0oooo
00@0oooo0P00000P0?ooo`000P3oool2000000X0oooo0P0000040?ooo`8000001@3oool2000001l0
oooo0P3o00080?ooo`<00000]03oool200000240oooo000K0?ooo`030000003oool0oooo01l0oooo
0P3o00080?ooo`<00000/`3oool200000240oooo000K0?ooo`030000003oool0oooo01l0oooo0P3o
00090?ooo`800000/P3oool200000280oooo000K0?ooo`030000003oool0oooo0200oooo0P3o0009
0?ooo`800000Z@3oool00`3o0000oooo0?ooo`050?ooo`8000008P3oool001/0oooo00<000000?oo
o`3oool0803oool30?l000P0oooo0`00002W0?ooo`<0o`001@3oool300000280oooo000K0?ooo`80
00008P3oool20?l000T0oooo0`00002V0?ooo`80o`001P3oool2000002<0oooo000K0?ooo`030000
003oool0oooo0240oooo0`3o00090?ooo`800000Y@3oool20?l000H0oooo0`00000S0?ooo`006`3o
ool00`000000oooo0?ooo`0R0?ooo`80o`002P3oool200000:@0oooo0P3o00060?ooo`800000903o
ool001/0oooo00<000000?ooo`3oool08`3oool20?l000T0oooo0`00002R0?ooo`80o`001`3oool2
000002@0oooo000K0?ooo`800000903oool20?l000X0oooo0`00002P0?ooo`<0o`001P3oool20000
02D0oooo000K0?ooo`030000003oool0oooo02@0oooo0P3o000:0?ooo`800000X03oool20?l000L0
oooo0P00000U0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`<0o`002P3oool2000009h0oooo
0P3o00070?ooo`8000009P3oool001/0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?oo
o`090?ooo`<00000W@3oool20?l000L0oooo0P00000V0?ooo`006`3oool2000003<0oooo0P00002L
0?ooo`80o`001`3oool3000002H0oooo000K0?ooo`030000003oool0oooo03<0oooo0P00002J0?oo
o`<0o`001`3oool2000002L0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00002I0?ooo`80
o`001`3oool3000002L0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0
2@3oool2000009P0oooo0`3o00070?ooo`800000:03oool000050?ooo`000000oooo0?ooo`000000
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool09`3oool30?l000/0oooo0P00002H0?ooo`030?l0003oool0oooo00D0oooo0`00000X0?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`050000003oool0oooo0000003oool01@0000040?oo
o`800000:@3oool20?l000/0oooo0`00002O0?ooo`800000:@3oool000050?ooo`000000oooo0?oo
o`000000203oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0Y0?ooo`80o`002`3oool2000009h0oooo0P00000Z0?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`0Y0?ooo`<0o`002`3oool2000009<0oooo00<0o`000?ooo`3oool0
1`3oool2000002X0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool0
00000`3oool2000000D0oooo00<000000?ooo`3oool0:P3oool30?l000X0oooo0`00002A0?ooo`<0
o`001`3oool2000002/0oooo00020?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0
0`3oool2000002`0oooo0P3o000;0?ooo`800000T@3oool20?l000P0oooo0P00000[0?ooo`006`3o
ool00`000000oooo0?ooo`0/0?ooo`80o`002`3oool2000008l0oooo0P3o00080?ooo`800000;03o
ool001/0oooo00<000000?ooo`3oool0;03oool30?l000X0oooo0`00002=0?ooo`<0o`00203oool2
000002`0oooo000K0?ooo`030000003oool0oooo02d0oooo0`3o000:0?ooo`800000S@3oool20?l0
00P0oooo0P00000]0?ooo`006`3oool00`000000oooo0?ooo`0^0?ooo`80o`002`3oool2000008/0
oooo0P3o00090?ooo`800000;@3oool001/0oooo0P00000`0?ooo`80o`002P3oool3000008T0oooo
0`3o00080?ooo`800000;P3oool001/0oooo00<000000?ooo`3oool0;`3oool30?l000X0oooo0`00
00280?ooo`80o`00203oool3000002h0oooo000K0?ooo`030000003oool0oooo0300oooo00<0o`00
0?ooo`3oool02P3oool3000008H0oooo0P3o00090?ooo`800000;`3oool001/0oooo00<000000?oo
o`3oool0?P3oool2000008D0oooo0`3o00080?ooo`<00000;`3oool001/0oooo0P0000100?ooo`80
0000P`3oool30?l000T0oooo0P00000`0?ooo`006`3oool00`000000oooo0?ooo`0d0?ooo`030?l0
003oool0oooo00P0oooo0`0000220?ooo`80o`002@3oool300000300oooo000K0?ooo`030000003o
ool0oooo03<0oooo0`3o000:0?ooo`<00000P03oool20?l000X0oooo0P00000a0?ooo`006`3oool0
0`000000oooo0?ooo`0d0?ooo`80o`002`3oool3000007h0oooo0`3o00090?ooo`800000<P3oool0
01/0oooo0P00000f0?ooo`80o`002`3oool3000007h0oooo00<0o`000?ooo`3oool01`3oool30000
0380oooo000K0?ooo`030000003oool0oooo03D0oooo0`3o000;0?ooo`800000R03oool2000003<0
oooo000K0?ooo`030000003oool0oooo03H0oooo0`3o000;0?ooo`800000QP3oool2000003@0oooo
00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo00<0
00000?ooo`3oool0=`3oool20?l000/0oooo0`0000240?ooo`<00000=03oool000050?ooo`000000
oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0>03oool20?l000/0oooo0`00001g0?ooo`030?l0003oool0oooo00T0oooo
0P00000e0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool00P3oool2000003T0oooo0`3o000;0?ooo`<00000M@3oool30?l000T0
oooo0`00000e0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo0000
0080oooo0`0000050?ooo`030000003oool0oooo03T0oooo0`3o000;0?ooo`<00000L`3oool30?l0
00T0oooo0`00000f0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j0?ooo`80o`00303oool3
00000740oooo0`3o000:0?ooo`800000=`3oool000050?ooo`000000oooo0?ooo`000000203oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>`3o
ool20?l000`0oooo0`00001_0?ooo`<0o`002P3oool3000003L0oooo00020?ooo`8000002P3oool2
000000<0oooo100000040?ooo`800000?03oool30?l000`0oooo0`00001]0?ooo`<0o`002`3oool2
000003P0oooo000K0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0303oool20000
06`0oooo0`3o000;0?ooo`800000>@3oool001/0oooo00<000000?ooo`3oool0C03oool2000006/0
oooo0P3o000;0?ooo`<00000>@3oool001/0oooo00<000000?ooo`3oool0C@3oool2000006T0oooo
0P3o000<0?ooo`800000>P3oool001/0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?oo
o`0:0?ooo`<00000I`3oool20?l000`0oooo0P00000k0?ooo`006`3oool200000400oooo0`3o000<
0?ooo`<00000I@3oool30?l000/0oooo0`00000k0?ooo`006`3oool00`000000oooo0?ooo`100?oo
o`<0o`00303oool3000006<0oooo0`3o000;0?ooo`<00000?03oool001/0oooo00<000000?ooo`3o
ool0@@3oool30?l000`0oooo0`00001S0?ooo`030?l0003oool0oooo00X0oooo0P00000m0?ooo`00
6`3oool00`000000oooo0?ooo`120?ooo`<0o`00303oool3000006h0oooo0P00000n0?ooo`006`3o
ool2000004@0oooo0`3o000<0?ooo`<00000K03oool3000003h0oooo000K0?ooo`030000003oool0
oooo04@0oooo0`3o000<0?ooo`<00000JP3oool3000003l0oooo000K0?ooo`030000003oool0oooo
04D0oooo0`3o000<0?ooo`<00000F@3oool20?l000h0oooo0P0000100?ooo`006`3oool00`000000
oooo0?ooo`160?ooo`<0o`00303oool3000005P0oooo0`3o000<0?ooo`800000@@3oool001/0oooo
0P0000180?ooo`<0o`00303oool3000005H0oooo0`3o000<0?ooo`<00000@@3oool001/0oooo00<0
00000?ooo`3oool0B03oool30?l000`0oooo0`00001D0?ooo`<0o`00303oool300000480oooo000K
0?ooo`030000003oool0oooo04T0oooo00<0o`000?ooo`3oool0303oool300000580oooo0`3o000=
0?ooo`800000@`3oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`1I0?ooo`<00000C`3oool40?l000d0oooo0P0000140?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1J0?ooo`<00000C@3oool30?l000h0oooo0`00
00140?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool2000004l0oooo00<0o`000?ooo`3oool02P3oool3000004/0
oooo0`3o000>0?ooo`<00000A@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000
oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`1=0?ooo`<0o`00303oool30000
04T0oooo0`3o000>0?ooo`<00000AP3oool000050?ooo`000000oooo0?ooo`000000203oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0CP3oool3
0?l000`0oooo100000160?ooo`<0o`003P3oool3000004L0oooo00001@3oool000000?ooo`3oool0
000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo04l0oooo103o000<0?ooo`<00000AP3oool00`3o0000oooo0?ooo`0<0?ooo`<00000B03o
ool00080oooo0P00000:0?ooo`800000103oool3000000@0oooo0P00001B0?ooo`<0o`00303oool3
000005<0oooo0`0000190?ooo`006`3oool00`000000oooo0?ooo`1B0?ooo`@0o`002`3oool30000
03l0oooo00<0o`000?ooo`3oool03`3oool2000004/0oooo000K0?ooo`030000003oool0oooo05@0
oooo0`3o000;0?ooo`<00000?@3oool30?l000h0oooo0`00001<0?ooo`006`3oool00`000000oooo
0?ooo`1E0?ooo`<0o`002`3oool4000003T0oooo103o000>0?ooo`<00000C@3oool001/0oooo0P00
001G0?ooo`@0o`002`3oool3000003L0oooo0`3o000?0?ooo`<00000CP3oool001/0oooo00<00000
0?ooo`3oool0F03oool30?l000/0oooo0`00000e0?ooo`<0o`003`3oool3000004l0oooo000K0?oo
o`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool02`3oool400000340oooo103o000?0?oo
o`<00000D03oool001/0oooo00<000000?ooo`3oool0GP3oool00`3o0000oooo0?ooo`080?ooo`<0
0000;P3oool40?l000l0oooo1000001A0?ooo`006`3oool00`000000oooo0?ooo`1M0?ooo`<0o`00
2P3oool4000002T0oooo1P3o000?0?ooo`<00000D`3oool001/0oooo0P00001O0?ooo`@0o`002@3o
ool4000002L0oooo103o000A0?ooo`<00000E03oool001/0oooo00<000000?ooo`3oool0H03oool5
0?l000P0oooo0`00000W0?ooo`030?l0003oool0oooo00l0oooo1000001E0?ooo`006`3oool00`00
0000oooo0?ooo`1Q0?ooo`L0o`001P3oool4000001l0oooo00<0o`000?ooo`3oool0503oool30000
05L0oooo000K0?ooo`030000003oool0oooo06@0oooo1@3o00070?ooo`@000006`3oool40?l001@0
oooo0`00001H0?ooo`006`3oool2000006P0oooo103o00060?ooo`D000005P3oool60?l001<0oooo
1000001I0?ooo`006`3oool00`000000oooo0?ooo`1Y0?ooo`<0o`001@3oool00`3o0000oooo0000
0004000000h0oooo00<0o`000?ooo`3oool01P3o000E0?ooo`<00000F`3oool001/0oooo00<00000
0?ooo`3oool0JP3oool00`3o0000oooo0?ooo`030?ooo`@0o`0000<0oooo0000000000000`00000;
0?ooo`P0o`005@3oool4000005`0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0700oooo3`3o00050?oo
o`H0o`005P3oool4000005h0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0780oooo3@3o0006
0?ooo`030?l0003oool0oooo01H0oooo1000001P0?ooo`0000D0oooo0000003oool0oooo00000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool2000007`0oooo1`00
000I0?ooo`H00000H@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0OP3oool8000000l0oooo
2@00001T0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo``0000000<0oooo00000000
00003000001V0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`250?oooa400000K03oool0
0080oooo0P00000:0?ooo`8000000`3oool4000000@0oooo0P00002=0?ooo`@00000LP3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.107864, -0.00655168, \
0.00394728, 0.000455358}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    \(2\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 8.25574 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .09727 -24 -4.5 ]
[.01131 .09727 0 4.5 ]
[.01131 .17983 -24 -4.5 ]
[.01131 .17983 0 4.5 ]
[.01131 .26239 -24 -4.5 ]
[.01131 .26239 0 4.5 ]
[.01131 .34494 -24 -4.5 ]
[.01131 .34494 0 4.5 ]
[.01131 .4275 -24 -4.5 ]
[.01131 .4275 0 4.5 ]
[.01131 .51006 -24 -4.5 ]
[.01131 .51006 0 4.5 ]
[.01131 .59262 -24 -4.5 ]
[.01131 .59262 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09727 m
.03006 .09727 L
s
[(0.01)] .01131 .09727 1 0 Mshowa
.02381 .17983 m
.03006 .17983 L
s
[(0.02)] .01131 .17983 1 0 Mshowa
.02381 .26239 m
.03006 .26239 L
s
[(0.03)] .01131 .26239 1 0 Mshowa
.02381 .34494 m
.03006 .34494 L
s
[(0.04)] .01131 .34494 1 0 Mshowa
.02381 .4275 m
.03006 .4275 L
s
[(0.05)] .01131 .4275 1 0 Mshowa
.02381 .51006 m
.03006 .51006 L
s
[(0.06)] .01131 .51006 1 0 Mshowa
.02381 .59262 m
.03006 .59262 L
s
[(0.07)] .01131 .59262 1 0 Mshowa
.125 Mabswid
.02381 .03123 m
.02756 .03123 L
s
.02381 .04774 m
.02756 .04774 L
s
.02381 .06425 m
.02756 .06425 L
s
.02381 .08076 m
.02756 .08076 L
s
.02381 .11378 m
.02756 .11378 L
s
.02381 .1303 m
.02756 .1303 L
s
.02381 .14681 m
.02756 .14681 L
s
.02381 .16332 m
.02756 .16332 L
s
.02381 .19634 m
.02756 .19634 L
s
.02381 .21285 m
.02756 .21285 L
s
.02381 .22936 m
.02756 .22936 L
s
.02381 .24588 m
.02756 .24588 L
s
.02381 .2789 m
.02756 .2789 L
s
.02381 .29541 m
.02756 .29541 L
s
.02381 .31192 m
.02756 .31192 L
s
.02381 .32843 m
.02756 .32843 L
s
.02381 .36146 m
.02756 .36146 L
s
.02381 .37797 m
.02756 .37797 L
s
.02381 .39448 m
.02756 .39448 L
s
.02381 .41099 m
.02756 .41099 L
s
.02381 .44401 m
.02756 .44401 L
s
.02381 .46053 m
.02756 .46053 L
s
.02381 .47704 m
.02756 .47704 L
s
.02381 .49355 m
.02756 .49355 L
s
.02381 .52657 m
.02756 .52657 L
s
.02381 .54308 m
.02756 .54308 L
s
.02381 .55959 m
.02756 .55959 L
s
.02381 .57611 m
.02756 .57611 L
s
.02381 .60913 m
.02756 .60913 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.015 w
.02381 .01472 m
.06244 .0777 L
.10458 .14562 L
.14415 .20795 L
.18221 .26588 L
.22272 .32469 L
.26171 .37782 L
.30316 .42983 L
.34309 .47486 L
.3815 .51284 L
.42237 .54681 L
.46172 .57258 L
.48147 .58276 L
.49955 .59036 L
.51896 .59664 L
.52966 .59924 L
.535 .6003 L
.53984 .60113 L
.54444 .6018 L
.54943 .60238 L
.55217 .60264 L
.55469 .60285 L
.55725 .60302 L
.55964 .60314 L
.5617 .60322 L
.56286 .60326 L
.56391 .60328 L
.56506 .6033 L
.56631 .60332 L
.56749 .60332 L
.56859 .60331 L
.56971 .6033 L
.57076 .60329 L
.57192 .60326 L
.57317 .60322 L
.5757 .60312 L
.57803 .60299 L
.58277 .60262 L
.58784 .60209 L
.59696 .60073 L
.6078 .59845 L
.61766 .59575 L
.63684 .58871 L
.65764 .57839 L
.69856 .54956 L
.73796 .51068 L
.77585 .4625 L
.81619 .39908 L
.85501 .32576 L
.89629 .2341 L
Mistroke
.93605 .13199 L
.97429 .02058 L
.97619 .01472 L
Mfstroke
1 0 0 r
.02 w
[ .05 .05 ] 0 setdash
.02381 .01472 m
.06244 .07877 L
.10458 .14729 L
.14415 .20974 L
.18221 .26748 L
.22272 .32583 L
.26171 .37838 L
.30316 .42968 L
.34309 .47402 L
.3815 .5114 L
.42237 .54483 L
.46172 .57025 L
.48147 .58032 L
.49955 .58786 L
.51896 .59413 L
.52966 .59674 L
.53984 .59865 L
.54478 .59938 L
.54943 .59994 L
.552 .6002 L
.55479 .60044 L
.5571 .60061 L
.55964 .60076 L
.56081 .60081 L
.56205 .60086 L
.56313 .6009 L
.5643 .60093 L
.56562 .60096 L
.56687 .60098 L
.56809 .60099 L
.56922 .60099 L
.57027 .60098 L
.57125 .60097 L
.57233 .60095 L
.57349 .60092 L
.57586 .60084 L
.57803 .60073 L
.58277 .60041 L
.58542 .60017 L
.58784 .59992 L
.59696 .59865 L
.60207 .59772 L
.6076 .59654 L
.61766 .59391 L
.63753 .58685 L
.65858 .57662 L
.69646 .55076 L
.7368 .5122 L
.77563 .46377 L
.8169 .39944 L
Mistroke
.85666 .32434 L
.89491 .23936 L
.93561 .13458 L
.97479 .01912 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00AP3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool4000002@0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000002@0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0P00000Z0?ooo`@000001P3oool004D0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000[0?ooo`030000003o
ool0oooo00D0oooo00150?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool08`3o
ool010000000oooo0?ooo`0000070?ooo`D000008`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
000[0?ooo`030000003oool0oooo00D0oooo00150?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool08P3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000002@0
oooo00@000000?ooo`3oool00000203oool3000002<0oooo00@000000?ooo`3oool000002@3oool2
000002`0oooo00<000000?ooo`3oool01@3oool004D0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`000000903o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000[0?ooo`030000003oool0oooo00D0oooo00150?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000008`3oool010000000oooo0?ooo`00
00090?ooo`800000903oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo02<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000Y0?ooo`<000001`3oool001/0
oooo00<000000?ooo`3oool0:03oool2000000X0oooo0P00000U0?ooo`8000002`3oool00`000000
oooo0?ooo`0S0?ooo`8000002P3oool3000002<0oooo0P00000:0?ooo`800000;03oool00`000000
oooo0?ooo`050?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001X0oooo0`00003j0?ooo`<000001P3oool001@0ooooo`00000=0000
00006P3oool4000000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool3000000H0oooo000K0?ooo`<00000
;`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0_0?ooo`<000001P3oool001/0oooo1000003h0?ooo`<000001P3o
ool001/0oooo1@00003f0?ooo`<000001`3oool001/0oooo00<000000?ooo`0000000P00003d0?oo
o`D0o`001`3oool001/0oooo00<000000?ooo`0000000`0000000`3o0000oooo0?ooo`3`0?ooo`D0
o`001`3oool001/0oooo00@000000?ooo`3oool000000`3o003b0?ooo`D0o`001`3oool001/0oooo
00<000000?ooo`3o00001@3o003a0?ooo`D0o`001`3oool001/0oooo0P0000000`3oool0o`000?l0
00030?l00?00oooo1P3o00070?ooo`006`3oool00`000000oooo0?ooo`060?l00>l0oooo1@3o0008
0?ooo`006`3oool010000000oooo0?ooo`3oool60?l00>h0oooo1@3o00080?ooo`006`3oool01000
0000oooo0?ooo`3oool60?l00>d0oooo1P3o00080?ooo`006`3oool2000000<0oooo1P3o003/0?oo
o`D0o`002@3oool001/0oooo00<000000?ooo`3oool00`3oool60?l00>/0oooo1@3o00090?ooo`00
6`3oool00`000000oooo0?ooo`030?ooo`H0o`00jP3oool60?l000T0oooo000K0?ooo`030000003o
ool0oooo00@0oooo1P3o003Y0?ooo`D0o`002P3oool001/0oooo00<000000?ooo`3oool0103oool7
0?l00>P0oooo1@3o000:0?ooo`006`3oool2000000H0oooo1P3o003W0?ooo`H0o`002P3oool001/0
oooo00<000000?ooo`3oool01P3oool60?l00>H0oooo1@3o000;0?ooo`000P3oool2000000@0oooo
00<000000?ooo`3oool00`3oool2000000<0oooo100000040?ooo`030000003oool0oooo00H0oooo
1`3o003U0?ooo`D0o`002`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool60?l00>D0
oooo1@3o000;0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool2000000T0oooo0`3o00000`000000oooo0?ooo`3S0?oo
o`030000003o0000o`0000<0o`002`3oool000050?ooo`000000oooo0?ooo`000000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2
0?l000<00000i03oool3000000h0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo1000
003S0?ooo`<000003P3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?oo
o`0000020?ooo`<000001@3oool00`000000oooo0?ooo`0;0?ooo`<00000hP3oool3000000l0oooo
00020?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool00`3oool2000000`0oooo1000
003Q0?ooo`<000003`3oool001/0oooo00<000000?ooo`3oool0303oool300000>00oooo1000000?
0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`@00000g`3oool300000100oooo000K0?ooo`03
0000003oool0oooo00d0oooo0`0000020?l00=`0oooo00@0o`000000000000000000403oool001/0
oooo00<000000?ooo`3oool03P3oool010000000o`000?l0003o003L0?ooo`<0o`004@3oool001/0
oooo0P00000>0?ooo`H0o`00fP3oool60?l000l0oooo000K0?ooo`030000003oool0oooo00d0oooo
1`3o003I0?ooo`D0o`00403oool001/0oooo00<000000?ooo`3oool03P3oool60?l00=P0oooo1P3o
000@0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`H0o`00e`3oool50?l00140oooo000K0?oo
o`800000403oool70?l00=H0oooo1@3o000A0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`H0
o`00e@3oool60?l00140oooo000K0?ooo`030000003oool0oooo0140oooo1P3o003D0?ooo`D0o`00
4P3oool001/0oooo00<000000?ooo`3oool04@3oool60?l00=@0oooo1@3o000B0?ooo`006`3oool2
000001<0oooo1P3o003B0?ooo`D0o`004`3oool001/0oooo00<000000?ooo`3oool04`3oool60?l0
0=40oooo1@3o000C0?ooo`006`3oool00`000000oooo0?ooo`0C0?ooo`H0o`00d03oool60?l001<0
oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool4000000@0oooo
00<000000?ooo`3oool0503oool60?l00<l0oooo1@3o000D0?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0E0?ooo`D0o`00c`3oool50?l001@0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`8000005P3oool60?l0
0<d0oooo1P3o000D0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`<0o`000P00003=
0?ooo`D0o`005@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0000
000300000</0oooo1P3o000E0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0I0?ooo`@0
0000b`3oool010000000o`000?l0003o000F0?ooo`000P3oool2000000X0oooo0P0000040?ooo`80
00001@3oool2000001/0oooo0`00003;0?ooo`<0000000<0o`000?ooo`3oool0503oool001/0oooo
00<000000?ooo`3oool06P3oool400000<T0oooo0`00000H0?ooo`006`3oool00`000000oooo0?oo
o`0K0?ooo`@00000b03oool3000001P0oooo000K0?ooo`030000003oool0oooo01`0oooo0P000000
0`3o0000oooo0?ooo`350?ooo`@00000603oool001/0oooo00<000000?ooo`3oool0703oool01000
0000o`000?l0003o00360?ooo`<000006@3oool001/0oooo0P00000M0?ooo`D0o`00a@3oool30000
01T0oooo000K0?ooo`030000003oool0oooo01/0oooo1`3o00330?ooo`@000006@3oool001/0oooo
00<000000?ooo`3oool0703oool60?l00<<0oooo0`3o000J0?ooo`006`3oool00`000000oooo0?oo
o`0M0?ooo`H0o`00`@3oool50?l001T0oooo000K0?ooo`8000007`3oool60?l00<00oooo1@3o000I
0?ooo`006`3oool00`000000oooo0?ooo`0N0?ooo`L0o`00_`3oool50?l001T0oooo000K0?ooo`03
0000003oool0oooo01l0oooo1P3o002n0?ooo`H0o`006@3oool001/0oooo00<000000?ooo`3oool0
803oool60?l00;d0oooo1@3o000J0?ooo`006`3oool200000240oooo1`3o002k0?ooo`H0o`006P3o
ool001/0oooo00<000000?ooo`3oool08@3oool60?l00;/0oooo1@3o000K0?ooo`006`3oool00`00
0000oooo0?ooo`0R0?ooo`H0o`00^@3oool60?l001/0oooo00020?ooo`800000103oool00`000000
oooo0?ooo`030?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool08`3oool60?l00;L0
oooo1P3o000L0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0S0?ooo`L0o`00]P3oool6
0?l001`0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`020?ooo`8000009@3oool50?l00;H0oooo1P3o000M0?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000
003oool0oooo02D0oooo0`3o00000`000000oooo0?ooo`2d0?ooo`D0o`007P3oool000050?ooo`00
0000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool09P3oool0103o0000000000000000002d0?ooo`H0o`007P3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool09`3oool400000;<0oooo1@3o000O0?ooo`000P3oool2
000000X0oooo0P0000040?ooo`8000001@3oool2000002T0oooo1000002a0?ooo`H0o`007`3oool0
01/0oooo00<000000?ooo`3oool0:@3oool300000;80oooo00@000000?l0003o0000o`00803oool0
01/0oooo00<000000?ooo`3oool0:@3oool400000;40oooo0`0000000`3o0000oooo0?ooo`0N0?oo
o`006`3oool00`000000oooo0?ooo`0Z0?ooo`<0000000<0o`000?ooo`3oool0[@3oool400000240
oooo000K0?ooo`030000003oool0oooo02/0oooo00@000000?l0003o0000o`00[P3oool300000280
oooo000K0?ooo`800000;03oool50?l00:`0oooo1000000R0?ooo`006`3oool00`000000oooo0?oo
o`0Z0?ooo`L0o`00Z`3oool3000002<0oooo000K0?ooo`030000003oool0oooo02/0oooo1P3o002[
0?ooo`<000008`3oool001/0oooo00<000000?ooo`3oool0;03oool60?l00:T0oooo00<0o`000000
00000000903oool001/0oooo0P00000^0?ooo`H0o`00YP3oool40?l000030000003oool0oooo0280
oooo000K0?ooo`030000003oool0oooo02d0oooo1P3o002V0?ooo`D0o`00903oool001/0oooo00<0
00000?ooo`3oool0;P3oool60?l00:@0oooo1`3o000S0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`H0o`00XP3oool70?l002@0oooo000K0?ooo`800000<03oool70?l00:40oooo1P3o000U0?oo
o`006`3oool00`000000oooo0?ooo`0`0?ooo`H0o`00X@3oool50?l002H0oooo000K0?ooo`030000
003oool0oooo0340oooo1P3o002O0?ooo`H0o`009P3oool00080oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3o
ool60?l009h0oooo1@3o000W0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b0?ooo`L0o`00
W03oool60?l002L0oooo00001@3oool000000?ooo`3oool0000000P0oooo00D000000?ooo`3oool0
00000?ooo`05000000@0oooo0P00000d0?ooo`D0o`00W@3oool60?l002L0oooo00001@3oool00000
0?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0=03oool30?l000800000W03oool50?l002P0oooo00001@3o
ool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
00050?ooo`030000003oool0oooo03D0oooo00<0o`000000000000000P00002J0?ooo`H0o`00:03o
ool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`800000
1@3oool00`000000oooo0?ooo`0g0?ooo`<00000VP3oool50?l002T0oooo00020?ooo`8000002P3o
ool2000000D0oooo00<000000?ooo`3oool00`3oool2000003P0oooo1000002H0?ooo`H0o`00:@3o
ool001/0oooo00<000000?ooo`3oool0>03oool4000009L0oooo1@3o000Z0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000UP3oool60?l002X0oooo000K0?ooo`030000003oool0oooo03T0
oooo100000000`3o0000oooo0?ooo`2B0?ooo`8000000`3o000[0?ooo`006`3oool00`000000oooo
0?ooo`0j0?ooo`8000000`3o002C0?ooo`<0000000<0oooo0?l0003oool0:P3oool001/0oooo0P00
000l0?ooo`D0o`00T@3oool4000002d0oooo000K0?ooo`030000003oool0oooo03X0oooo1`3o002@
0?ooo`<00000;P3oool001/0oooo00<000000?ooo`3oool0>`3oool70?l008d0oooo00<0o`000000
000000000P00000^0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`H0o`00S@3oool30?l00003
0000003oool0oooo02d0oooo000K0?ooo`800000?P3oool60?l008/0oooo1P3o000^0?ooo`006`3o
ool00`000000oooo0?ooo`0m0?ooo`L0o`00RP3oool50?l002l0oooo000K0?ooo`030000003oool0
oooo03h0oooo1`3o00280?ooo`H0o`00;`3oool001/0oooo00<000000?ooo`3oool0?`3oool70?l0
08H0oooo1P3o000`0?ooo`006`3oool200000440oooo1P3o00260?ooo`H0o`00<03oool001/0oooo
00<000000?ooo`3oool0@@3oool60?l008@0oooo1P3o000a0?ooo`006`3oool00`000000oooo0?oo
o`110?ooo`L0o`00P`3oool50?l00380oooo00020?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0@P3oool70?l00840oooo1P3o000b
0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`130?ooo`D0o`0000<000000?ooo`3oool0O`3o
ool2000000<0o`00<`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo0080oooo0P0000150?ooo`<0o`000`0000200?ooo`<00000
00<0oooo0?l0003oool0<P3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo
0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`150?ooo`030?l00000000000000080
0000O`3oool3000003H0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04L0oooo1000001m0?oo
o`@00000=P3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B03oool4000007`0oooo0`00000g
0?ooo`000P3oool2000000X0oooo0P0000030?ooo`@00000103oool2000004X0oooo1000001j0?oo
o`@00000=`3oool001/0oooo00<000000?ooo`3oool0BP3oool4000000030?l0003oool0oooo07D0
oooo00@0o`000000000000000000>03oool001/0oooo00<000000?ooo`3oool0B`3oool2000000<0
o`00M@3oool30?l000030000003oool0oooo03L0oooo000K0?ooo`030000003oool0oooo04`0oooo
1@3o001c0?ooo`D0o`00>@3oool001/0oooo00<000000?ooo`3oool0B`3oool70?l00740oooo1`3o
000h0?ooo`006`3oool2000004d0oooo1`3o001_0?ooo`L0o`00>@3oool001/0oooo00<000000?oo
o`3oool0C@3oool70?l006d0oooo1`3o000j0?ooo`006`3oool00`000000oooo0?ooo`1>0?ooo`L0
o`00K03oool60?l003/0oooo000K0?ooo`030000003oool0oooo04l0oooo1`3o001Z0?ooo`H0o`00
?03oool001/0oooo0P00001A0?ooo`L0o`00J03oool70?l003`0oooo000K0?ooo`030000003oool0
oooo0540oooo1P3o001W0?ooo`L0o`00?@3oool001/0oooo00<000000?ooo`3oool0DP3oool60?l0
06D0oooo1`3o000n0?ooo`006`3oool00`000000oooo0?ooo`1C0?ooo`H0o`00I03oool60?l003l0
oooo000K0?ooo`800000E03oool70?l00680oooo1P3o00100?ooo`006`3oool00`000000oooo0?oo
o`1D0?ooo`L0o`00H03oool70?l00400oooo000K0?ooo`030000003oool0oooo05D0oooo1@3o0002
000005h0oooo1`3o00110?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo0`3o0004000005h0oooo1@3o00120?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0000000@00000G03o
ool2000000<0o`00@`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo0P00001K0?ooo`D00000FP3oool400000003
0?l0003oool0oooo0480oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3o
ool000000P3oool3000000D0oooo00<000000?ooo`3oool0F`3oool5000000030?ooo`3o0000oooo
05D0oooo1@0000150?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1M0?ooo`<000000`3o001D
0?ooo`D00000AP3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0GP3oool00`000000o`000?l0
00030?l00500oooo00<0o`000?ooo`0000000`0000180?ooo`000P3oool2000000X0oooo0P000004
0?ooo`<00000103oool2000005l0oooo1`3o001>0?ooo`<0o`000`0000190?ooo`006`3oool00`00
0000oooo0?ooo`1O0?ooo`P0o`00B`3oool50?l000030000003oool0oooo04P0oooo000K0?ooo`03
0000003oool0oooo0600oooo203o00190?ooo`L0o`00BP3oool001/0oooo00<000000?ooo`3oool0
H@3oool80?l004L0oooo1`3o001;0?ooo`006`3oool2000006<0oooo2@3o00150?ooo`H0o`00C03o
ool001/0oooo00<000000?ooo`3oool0I03oool80?l004<0oooo1P3o001=0?ooo`006`3oool00`00
0000oooo0?ooo`1T0?ooo`X0o`00?`3oool80?l004d0oooo000K0?ooo`030000003oool0oooo06H0
oooo2P3o000l0?ooo`P0o`00CP3oool001/0oooo00<000000?ooo`3oool0I`3oool80?l003/0oooo
2P3o001>0?ooo`006`3oool2000006X0oooo1P3o00000`000000oooo0?ooo`0g0?ooo`T0o`00D03o
ool001/0oooo00<000000?ooo`3oool0J`3oool30?l000<00000=P3oool:0?l00540oooo000K0?oo
o`030000003oool0oooo06d0oooo00<0o`000000000000000`00000d0?ooo`P0o`00D`3oool001/0
oooo00<000000?ooo`3oool0K`3oool600000340oooo0P0000060?l005@0oooo000K0?ooo`800000
L@3oool5000000D0o`00:P3oool5000000<0o`00EP3oool001/0oooo00<000000?ooo`3oool0LP3o
ool3000000T0o`009@3oool5000000030?ooo`3o0000o`0005L0oooo000K0?ooo`030000003oool0
oooo07@0oooo00<000000?l0003o00002P3o000L0?ooo`<0o`0000<0oooo0000000000001000001K
0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1e0?ooo`h0o`004`3oool0103o0000oooo0?ooo`3oool7
0?l000@00000G@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0M@3ooolB0?l000`0oooo3P3o
0002000005l0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`800000NP3oool>0?l000P0oooo4P3o00000`000000oooo
0?ooo`1N0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1m0?ooo`X0o`002000000A0?l00680
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0800oooo1`3o0008000000h0o`00I@3oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0P@3oool60?l000P00000303o001W0?ooo`000P3oool2
000000X0oooo0P0000030?ooo`@00000103oool2000008D0oooo00<0o`000?ooo`3oool0103oool4
000000L0o`00K03oool001/0oooo00<000000?ooo`3oool0TP3oool00`3o0000oooo0?ooo`1]0?oo
o`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooob40oooo003o0?ooob40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.107864, -0.00655168, \
0.00394728, 0.000455358}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
WindowSize->{889, 858},
WindowMargins->{{295, Automatic}, {Automatic, 153}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 1323, 26, 479, "Subtitle"],
Cell[3102, 81, 34, 0, 51, "Subtitle"],
Cell[3139, 83, 274, 5, 64, "Input"],

Cell[CellGroupData[{
Cell[3438, 92, 41, 1, 27, "Input"],
Cell[3482, 95, 334, 5, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3853, 105, 42, 1, 27, "Input"],
Cell[3898, 108, 51, 1, 29, "Output"]
}, Open  ]],
Cell[3964, 112, 345, 7, 78, "Input"],
Cell[4312, 121, 68, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[4405, 126, 44, 1, 27, "Input"],
Cell[4452, 129, 143, 3, 27, "Output"]
}, Open  ]],
Cell[4610, 135, 70, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[4705, 140, 38, 1, 27, "Input"],
Cell[4746, 143, 55, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4838, 149, 59, 1, 46, "Input"],
Cell[4900, 152, 57, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4994, 158, 566, 11, 139, "Input"],
Cell[5563, 171, 35, 1, 27, "Output"],
Cell[5601, 174, 25728, 624, 186, 5355, 368, "GraphicsData", "PostScript", \
"Graphics"],
Cell[31332, 800, 130, 3, 27, "Output"],
Cell[31465, 805, 35, 1, 27, "Output"],
Cell[31503, 808, 22699, 588, 186, 5359, 369, "GraphicsData", "PostScript", \
"Graphics"],
Cell[54205, 1398, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

